@@ -1,7 +1,9 @@
 """
 python version compatibility code
 """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
 import codecs
 import functools
@@ -11,11 +13,12 @@ import sys
 from contextlib import contextmanager
 
 import py
+import six
+from six import text_type
 
 import _pytest
-from _pytest.outcomes import TEST_OUTCOME, fail
-from six import text_type
-import six
+from _pytest.outcomes import fail
+from _pytest.outcomes import TEST_OUTCOME
 
 try:
     import enum
@@ -331,6 +334,14 @@ def safe_getattr(object, name, default):
         return default
 
 
+def safe_isclass(obj):
+    """Ignore any exception via isinstance on Python 3."""
+    try:
+        return isclass(obj)
+    except Exception:
+        return False
+
+
 def _is_unittest_unexpected_success_a_failure():
     """Return if the test suite should fail if an @expectedFailure unittest test PASSES.
 
@@ -417,3 +428,16 @@ class FuncargnamesCompatAttr(object):
     def funcargnames(self):
         """ alias attribute for ``fixturenames`` for pre-2.3 compatibility"""
         return self.fixturenames
+
+
+if six.PY2:
+
+    def lru_cache(*_, **__):
+        def dec(fn):
+            return fn
+
+        return dec
+
+
+else:
+    from functools import lru_cache  # noqa: F401
